==> developer-center-api-1.7.7-20170223.072418-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/mainmeet/MainMeetThemeDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.mainmeet;

import com.google.common.collect.Lists;

import java.io.Serializable;
import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * Created by liuyao on 2017/1/24.
 * 主会场皮肤
 */
public class MainMeetThemeDto implements Serializable{
    private static final long serialVersionUID = -4699048758730873160L;

    public static final int STATUS_HIDE = 0;
    public static final int STATUS_SHOW = 1;

    private Long id;
    private String themeName;
    private String themeFileUrl;
    private String md5;
    private Integer showStatus;
    private List<MainMeetThemeActivityDto> activityList = Collections.emptyList();
    private String htmlUrl;
    private String jsUrl;
    private String cssUrl;
    private Long adminId;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getThemeName() {
        return themeName;
    }

    public void setThemeName(String themeName) {
        this.themeName = themeName;
    }

    public String getThemeFileUrl() {
        return themeFileUrl;
    }

    public void setThemeFileUrl(String themeFileUrl) {
        this.themeFileUrl = themeFileUrl;
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public Integer getShowStatus() {
        return showStatus;
    }

    public void setShowStatus(Integer showStatus) {
        this.showStatus = showStatus;
    }

    public List<MainMeetThemeActivityDto> getActivityList() {
        return activityList;
    }

    public void setActivityList(List<MainMeetThemeActivityDto> activityList) {
        this.activityList = activityList;
    }

    public String getHtmlUrl() {
        return htmlUrl;
    }

    public void setHtmlUrl(String htmlUrl) {
        this.htmlUrl = htmlUrl;
    }

    public String getJsUrl() {
        return jsUrl;
    }

    public void setJsUrl(String jsUrl) {
        this.jsUrl = jsUrl;
    }

    public String getCssUrl() {
        return cssUrl;
    }

    public void setCssUrl(String cssUrl) {
        this.cssUrl = cssUrl;
    }

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> developer-center-api-3.5.59-sources.jar: cn/com/duiba/developer/center/api/domain/dto/mainmeet/MainMeetThemeDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.mainmeet;

import cn.com.duiba.developer.center.api.domain.dto.CodeDto;

import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * Created by liuyao on 2017/1/24.
 * 主会场皮肤
 */
public class MainMeetThemeDto implements CodeDto {
    private static final long serialVersionUID = -4699048758730873160L;

    public static final int STATUS_HIDE = 0;
    public static final int STATUS_SHOW = 1;

    private Long id;
    private String themeName;
    private String themeFileUrl;
    private String md5;
    private Integer showStatus;
    private List<MainMeetThemeActivityDto> activityList = Collections.emptyList();
    private String htmlUrl;
    private String jsUrl;
    private String cssUrl;
    private Long adminId;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getThemeName() {
        return themeName;
    }

    public void setThemeName(String themeName) {
        this.themeName = themeName;
    }

    public String getThemeFileUrl() {
        return themeFileUrl;
    }

    public void setThemeFileUrl(String themeFileUrl) {
        this.themeFileUrl = themeFileUrl;
    }

    @Override
    public String getConfigUrl() {
        return this.getThemeFileUrl();
    }

    public String getMd5() {
        return md5;
    }

    public void setMd5(String md5) {
        this.md5 = md5;
    }

    public Integer getShowStatus() {
        return showStatus;
    }

    public void setShowStatus(Integer showStatus) {
        this.showStatus = showStatus;
    }

    public List<MainMeetThemeActivityDto> getActivityList() {
        return activityList;
    }

    public void setActivityList(List<MainMeetThemeActivityDto> activityList) {
        this.activityList = activityList;
    }

    public String getHtmlUrl() {
        return htmlUrl;
    }

    public void setHtmlUrl(String htmlUrl) {
        this.htmlUrl = htmlUrl;
    }

    public String getJsUrl() {
        return jsUrl;
    }

    public void setJsUrl(String jsUrl) {
        this.jsUrl = jsUrl;
    }

    public String getCssUrl() {
        return cssUrl;
    }

    public void setCssUrl(String cssUrl) {
        this.cssUrl = cssUrl;
    }

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
